@@ -4,7 +4,7 @@ package Text::SimpleTable;
 
 use strict;
 
-our $VERSION = '1.1';
+our $VERSION = '1.3';
 
 # Top
 our $TOP_LEFT      = '.-';
@@ -52,6 +52,9 @@ sub new {
         }
         else { $width = $arg }
 
+        # Fix size
+        $width = 2 if $width < 2;
+
         # Wrap
         my $title = $name ? $self->_wrap($name, $width) : [];
 
